@@ -2,14 +2,14 @@
 **  Copyright (c) 2006-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-config.h,v 1.20 2007/05/23 01:27:35 msk Exp $
+**  $Id: dkim-config.h,v 1.28 2007/08/01 22:26:08 msk Exp $
 */
 
 #ifndef _DKIM_CONFIG_H_
 #define _DKIM_CONFIG_H_
 
 #ifndef lint
-static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.20 2007/05/23 01:27:35 msk Exp $";
+static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.28 2007/08/01 22:26:08 msk Exp $";
 #endif /* !lint */
 
 struct configdef dkimf_config[] =
@@ -19,6 +19,7 @@ struct configdef dkimf_config[] =
 	{ "Background",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "BodyLengths",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "Canonicalization",		CONFIG_TYPE_STRING,	FALSE },
+	{ "ClockDrift",			CONFIG_TYPE_INTEGER,	FALSE },
 	{ "Diagnostics",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef _FFR_ZTAGS
 	{ "DiagnosticDirectory",	CONFIG_TYPE_STRING,	FALSE },
@@ -26,9 +27,6 @@ struct configdef dkimf_config[] =
 	{ "DNSTimeout",			CONFIG_TYPE_INTEGER,	FALSE },
 	{ "Domain",			CONFIG_TYPE_STRING,	FALSE },
 	{ "ExternalIgnoreList",		CONFIG_TYPE_STRING,	FALSE },
-#ifdef _FFR_FLUSH_HEADERS
-	{ "FlushHeaders",		CONFIG_TYPE_BOOLEAN,	FALSE },
-#endif /* _FFR_FLUSH_HEADERS */
 	{ "KeyFile",			CONFIG_TYPE_STRING,	FALSE },
 	{ "KeyList",			CONFIG_TYPE_STRING,	FALSE },
 	{ "InternalHosts",		CONFIG_TYPE_STRING,	FALSE },
@@ -48,6 +46,9 @@ struct configdef dkimf_config[] =
 	{ "POPDBFile",			CONFIG_TYPE_STRING,	FALSE },
 #endif /* POPAUTH */
 	{ "Quarantine",			CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "RemoveARAll",		CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "RemoveARFrom",		CONFIG_TYPE_STRING,	FALSE },
+	{ "RemoveOldSignatures",	CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef _FFR_REQUIRED_HEADERS
 	{ "RequiredHeaders",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #endif /* _FFR_REQUIRED_HEADERS */
@@ -64,6 +65,7 @@ struct configdef dkimf_config[] =
 #endif /* _FFR_STATS */
 	{ "SubDomains",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "Syslog",			CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "SyslogSuccess",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "UserID",			CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_VBR
 	{ "VBR-Certifiers",		CONFIG_TYPE_STRING,	FALSE },
