@@ -2,14 +2,14 @@
 **  Copyright (c) 2004, 2005, 2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: util.h,v 1.11 2007/08/15 01:10:44 msk Exp $
+**  $Id: util.h,v 1.13 2007/09/04 22:32:08 msk Exp $
 */
 
 #ifndef _UTIL_H_
 #define _UTIL_H_
 
 #ifndef lint
-static char util_h_id[] = "@(#)$Id: util.h,v 1.11 2007/08/15 01:10:44 msk Exp $";
+static char util_h_id[] = "@(#)$Id: util.h,v 1.13 2007/09/04 22:32:08 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -40,12 +40,12 @@ extern size_t dkimf_inet_ntoa __P((struct in_addr, char *, size_t));
 #ifdef POPAUTH
 extern int dkimf_initpopauth __P((void));
 #endif /* POPAUTH */
-extern bool dkimf_load_list __P((FILE *, struct Peer **));
-extern void dkimf_lowercase __P((char *));
+extern bool dkimf_load_list __P((FILE *, char **, struct Peer **));
+extern void dkimf_lowercase __P((u_char *));
 extern void dkimf_mkpath __P((char *, size_t, char *, char *));
 extern void dkimf_optlist __P((FILE *));
 extern void dkimf_setmaxfd __P((void));
 extern void dkimf_stripcr __P((char *));
-extern void dkimf_trimspaces __P((char *));
+extern void dkimf_trimspaces __P((u_char *));
 
 #endif /* _UTIL_H_ */
