@@ -6,7 +6,7 @@
 #ifdef _FFR_QUERY_CACHE
 
 #ifndef lint
-static char dkim_cache_c_id[] = "@(#)$Id: dkim-cache.c,v 1.16 2007/07/16 19:17:59 msk Exp $";
+static char dkim_cache_c_id[] = "@(#)$Id: dkim-cache.c,v 1.17 2007/09/07 00:28:57 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -45,11 +45,6 @@ static char dkim_cache_c_id[] = "@(#)$Id: dkim-cache.c,v 1.16 2007/07/16 19:17:5
 				  DB_VERSION_MINOR >= (y)) || \
 				 DB_VERSION_MAJOR > (x))
 
-/* local definitions needed for DNS queries */
-#ifndef MAXHOSTNAMELEN
-# define MAXHOSTNAMELEN		256
-#endif /* ! MAXHOSTNAMELEN */
-
 /* data types */
 struct dkim_cache_entry
 {
@@ -488,7 +483,7 @@ dkim_cache_expire(DB *db, int ttl, int *err)
 #endif /* DB_VERSION_CHECK(2,0,0) */
 	DBT q;
 	DBT d;
-	char name[MAXHOSTNAMELEN + 1];
+	char name[DKIM_MAXHOSTNAMELEN + 1];
 	struct dkim_cache_entry ce;
 
 	assert(db != NULL);
