@@ -4,12 +4,12 @@
 */
 
 #ifndef lint
-static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.20 2007/08/20 22:52:26 msk Exp $";
+static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.22 2007/09/07 00:28:57 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
 #include <sys/param.h>
-#include <sys/param.h>
+#include <sys/types.h>
 #include <assert.h>
 #include <string.h>
 #include <ctype.h>
@@ -363,15 +363,15 @@ dkim_canon_selecthdrs(DKIM *dkim, u_char *hdrlist, struct dkim_header **ptrs,
 	{
 		dkim->dkim_hdrlist = dkim_malloc(dkim->dkim_libhandle,
 		                                 dkim->dkim_closure,
-		                                 MAXHEADER);
+		                                 DKIM_MAXHEADER);
 		if (dkim->dkim_hdrlist == NULL)
 		{
 			dkim_error(dkim, "unable to allocate %d bytes(s)",
-			           MAXHEADER);
+			           DKIM_MAXHEADER);
 			return -1;
 		}
 	}
-	sm_strlcpy(dkim->dkim_hdrlist, hdrlist, MAXHEADER);
+	sm_strlcpy(dkim->dkim_hdrlist, hdrlist, DKIM_MAXHEADER);
 
 	/* mark all headers as not used */
 	for (hdr = dkim->dkim_hhead; hdr != NULL; hdr = hdr->hdr_next)
@@ -408,7 +408,7 @@ dkim_canon_selecthdrs(DKIM *dkim, u_char *hdrlist, struct dkim_header **ptrs,
 	{
 		lhdrs[c] = NULL;
 
-		len = MIN(MAXHEADER, strlen(hdrs[c]));
+		len = MIN(DKIM_MAXHEADER, strlen(hdrs[c]));
 
 		for (hdr = dkim->dkim_hhead; hdr != NULL; hdr = hdr->hdr_next)
 		{
@@ -987,7 +987,7 @@ dkim_canon_signature(DKIM *dkim, struct dkim_header *hdr)
 
 	if (dkim->dkim_hdrbuf == NULL)
 	{
-		dkim->dkim_hdrbuf = dkim_dstring_new(dkim, MAXHEADER, 0);
+		dkim->dkim_hdrbuf = dkim_dstring_new(dkim, DKIM_MAXHEADER, 0);
 		if (dkim->dkim_hdrbuf == NULL)
 			return DKIM_STAT_NORESOURCE;
 	}
