@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.22 2007/08/14 20:40:52 msk Exp $";
+static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.25 2007/09/07 00:28:57 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -37,9 +37,6 @@ static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.22 2007/08/14 20:40:52
 extern void dkim_error __P((DKIM *, const char *, ...));
 
 /* local definitions needed for DNS queries */
-#ifndef MAXHOSTNAMELEN
-# define MAXHOSTNAMELEN		256
-#endif /* ! MAXHOSTNAMELEN */
 #define MAXPACKET		8192
 #if defined(__RES) && (__RES >= 19940415)
 # define RES_UNC_T		char *
@@ -87,7 +84,7 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 	unsigned char *cp;
 	unsigned char *eom;
 	unsigned char *eob;
-	char qname[MAXHOSTNAMELEN + 1];
+	char qname[DKIM_MAXHOSTNAMELEN + 1];
 	unsigned char ansbuf[MAXPACKET];
 #if USE_ARLIB
 	struct timeval timeout;
@@ -314,36 +311,67 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 		return DKIM_STAT_CANTVRFY;
 
 	/*
-	**  Extract the data from the first answer.
+	**  Extract the data from the first TXT answer.
 	*/
 
-	/* grab the label, even though we know what we asked... */
-	if ((n = dn_expand((unsigned char *) &ansbuf, eom, cp,
-	                   (RES_UNC_T) qname, sizeof qname)) < 0)
+	while (--ancount >= 0 && cp < eom)
 	{
-		dkim_error(dkim, "`%s' reply corrupt", qname);
-		return DKIM_STAT_INTERNAL;
-	}
-	/* ...and move past it */
-	cp += n;
+		/* grab the label, even though we know what we asked... */
+		if ((n = dn_expand((unsigned char *) &ansbuf, eom, cp,
+		                   (RES_UNC_T) qname, sizeof qname)) < 0)
+		{
+			dkim_error(dkim, "`%s' reply corrupt", qname);
+			return DKIM_STAT_INTERNAL;
+		}
+		/* ...and move past it */
+		cp += n;
 
-	/* extract the type and class */
-	if (cp + INT16SZ + INT16SZ > eom)
-	{
-		dkim_error(dkim, "`%s' reply corrupt", qname);
-		return DKIM_STAT_INTERNAL;
-	}
-	GETSHORT(type, cp);
-	GETSHORT(class, cp);
+		/* extract the type and class */
+		if (cp + INT16SZ + INT16SZ > eom)
+		{
+			dkim_error(dkim, "`%s' reply corrupt", qname);
+			return DKIM_STAT_INTERNAL;
+		}
+
+		GETSHORT(type, cp);
+		GETSHORT(class, cp);
 
 #ifdef _FFR_QUERY_CACHE
-	/* get the TTL */
-	GETLONG(ttl, cp);
+		/* get the TTL */
+		GETLONG(ttl, cp);
 #else /* _FFR_QUERY_CACHE */
-	/* skip the TTL */
-	cp += INT32SZ;
+		/* skip the TTL */
+		cp += INT32SZ;
 #endif /* _FFR_QUERY_CACHE */
 
+		/* skip CNAME if found; assume it was resolved */
+		if (type == T_CNAME)
+		{
+			char chost[DKIM_MAXHOSTNAMELEN + 1];
+
+			n = dn_expand((u_char *) &ansbuf, eom, cp,
+			              chost, DKIM_MAXHOSTNAMELEN);
+			cp += n;
+			continue;
+		}
+		else if (type != T_TXT)
+		{
+			dkim_error(dkim, "`%s' reply was unexpected type %d",
+			           qname, type);
+			return DKIM_STAT_INTERNAL;
+		}
+
+		/* found a record we can use; break */
+		break;
+	}
+
+	/* if ancount went below 0, there were no good records */
+	if (ancount < 0)
+	{
+		dkim_error(dkim, "`%s' reply was unresolved CNAME", qname);
+		return DKIM_STAT_INTERNAL;
+	}
+
 	/* get payload length */
 	if (cp + INT16SZ > eom)
 	{
@@ -352,7 +380,11 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 	}
 	GETSHORT(n, cp);
 
-	/* XXX -- maybe deal with a partial reply rather than require it all */
+	/*
+	**  XXX -- maybe deal with a partial reply rather than require
+	**  	   it all
+	*/
+
 	if (cp + n > eom)
 	{
 		dkim_error(dkim, "`%s' reply corrupt", qname);
@@ -469,7 +501,7 @@ dkim_get_key_file(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 			}
 		}
 
-		if (strcmp(name, buf) == 0)
+		if (strcasecmp(name, buf) == 0)
 		{
 			sm_strlcpy(buf, p2, buflen);
 			fclose(f);
