@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.17 2007/08/14 20:40:52 msk Exp $";
+static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.19 2007/09/07 00:28:57 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -41,9 +41,6 @@ static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.17 2007/08/14 20:40
 extern void dkim_error __P((DKIM *, const char *, ...));
 
 /* local definitions needed for DNS queries */
-#ifndef MAXHOSTNAMELEN
-# define MAXHOSTNAMELEN		256
-#endif /* ! MAXHOSTNAMELEN */
 #define MAXPACKET		8192
 #if defined(__RES) && (__RES >= 19940415)
 # define RES_UNC_T		char *
@@ -185,7 +182,7 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, unsigned char *buf,
 	unsigned char *cp;
 	unsigned char *eom;
 	unsigned char ansbuf[MAXPACKET];
-	unsigned char namebuf[MAXHOSTNAMELEN + 1];
+	unsigned char namebuf[DKIM_MAXHOSTNAMELEN + 1];
 	unsigned char outbuf[BUFRSZ + 1];
 #if USE_ARLIB
 	struct timeval timeout;
@@ -427,30 +424,54 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, unsigned char *buf,
 	if (ancount == 0)
 		return 0;
 
-	/* grab the label, even though we know what we asked... */
-	if ((n = dn_expand((unsigned char *) &ansbuf, eom, cp,
-	                   (RES_UNC_T) namebuf, sizeof namebuf)) < 0)
+	/* walk through the answers looking for a TXT record */
+	while (--ancount >= 0 && cp < eom)
 	{
-		dkim_error(dkim, "`%s' reply corrupt", query);
-		return -1;
-	}
-	/* ...and move past it */
-	cp += n;
+		/* grab the label, even though we know what we asked... */
+		if ((n = dn_expand((unsigned char *) &ansbuf, eom, cp,
+		                   (RES_UNC_T) namebuf, sizeof namebuf)) < 0)
+		{
+			dkim_error(dkim, "`%s' reply corrupt", query);
+			return -1;
+		}
+		/* ...and move past it */
+		cp += n;
 
-	/* extract the type and class */
-	if (cp + INT16SZ + INT16SZ > eom)
-	{
-		dkim_error(dkim, "`%s' reply corrupt", query);
-		return -1;
-	}
-	GETSHORT(type, cp);
-	GETSHORT(class, cp);
+		/* extract the type and class */
+		if (cp + INT16SZ + INT16SZ > eom)
+		{
+			dkim_error(dkim, "`%s' reply corrupt", query);
+			return -1;
+		}
+		GETSHORT(type, cp);
+		GETSHORT(class, cp);
 
-	/* reject anything that's not valid (stupid wildcards) */
-	if (type != T_TXT || class != C_IN)
+		/* handle a CNAME (skip it; assume it was resolved) */
+		if (type == T_CNAME)
+		{
+			char chost[DKIM_MAXHOSTNAMELEN + 1];
+
+			n = dn_expand((u_char *) &ansbuf, eom, cp,
+			              chost, DKIM_MAXHOSTNAMELEN);
+			cp += n;
+			continue;
+		}
+		else if (type != T_TXT)
+		{
+			/* reject anything not valid (stupid wildcards) */
+			dkim_error(dkim, "`%s' unexpected reply class/type",
+			           query);
+			return -1;
+		}
+
+		/* process a TXT */
+		break;
+	}
+
+	if (ancount < 0)
 	{
-		dkim_error(dkim, "`%s' unexpected reply class/type", query);
-		return -1;
+		dkim_error(dkim, "`%s' reply was unresolved CNAME", query);
+		return DKIM_STAT_INTERNAL;
 	}
 
 #ifdef _FFR_QUERY_CACHE
@@ -469,13 +490,7 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, unsigned char *buf,
 	GETSHORT(n, cp);
 
 	/* XXX -- maybe deal with a partial reply rather than require it all */
-	if (cp + n > eom)
-	{
-		dkim_error(dkim, "`%s' reply corrupt", query);
-		return -1;
-	}
-
-	if (n > BUFRSZ)
+	if (cp + n > eom || n > BUFRSZ)
 	{
 		dkim_error(dkim, "`%s' reply corrupt", query);
 		return -1;
