@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.26 2007/08/09 15:05:01 msk Exp $";
+static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.27 2007/09/06 08:01:40 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -148,6 +148,12 @@ static struct nametable prv_results[] =		/* result codes */
 	{ "Resource unavailable",	DKIM_STAT_NORESOURCE },
 	{ "Internal error",		DKIM_STAT_INTERNAL },
 	{ "Revoked key",		DKIM_STAT_REVOKED },
+	{ "Invalid parameter",		DKIM_STAT_INVALID },
+	{ "Not implemented",		DKIM_STAT_NOTIMPLEMENT },
+	{ "Key retrieval failed",	DKIM_STAT_KEYFAIL },
+	{ "Reject requested",		DKIM_STAT_CBREJECT },
+	{ "Invalid result",		DKIM_STAT_CBINVALID },
+	{ "Try again later",		DKIM_STAT_CBTRYAGAIN },
 	{ NULL,				-1 },
 };
 struct nametable *results = prv_results;
