@@ -7,7 +7,7 @@
 #define _DKIM_TABLES_H_
 
 #ifndef lint
-static char dkim_tables_h_id[] = "@(#)$Id: dkim-tables.h,v 1.7 2007/06/25 20:24:47 msk Exp $";
+static char dkim_tables_h_id[] = "@(#)$Id: dkim-tables.h,v 1.11 2007/08/09 07:22:17 msk Exp $";
 #endif /* !lint */
 
 /* structures */
@@ -25,7 +25,7 @@ struct chartable
 
 /* tables */
 struct chartable *keyparams;
-struct chartable *pflags;
+struct chartable *policyflags;
 
 struct nametable *algorithms;
 struct nametable *canonicalizations;
@@ -33,9 +33,11 @@ struct nametable *hashes;
 struct nametable *keytypes;
 struct nametable *policies;
 struct nametable *policyparams;
+struct nametable *policyresults;
 struct nametable *querytypes;
 struct nametable *results;
 struct nametable *settypes;
+struct nametable *sigerrors;
 struct nametable *sigparams;
 
 /* prototypes */
