@@ -7,7 +7,7 @@
 #define _DKIM_H_
 
 #ifndef lint
-static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.129 2007/08/21 12:38:21 msk Exp $";
+static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.134 2007/09/07 00:28:57 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -31,7 +31,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.129 2007/08/21 12:38:21 msk Exp $
 **  	pp == patch number
 */
 
-#define	DKIM_LIB_VERSION	0x02010200
+#define	DKIM_LIB_VERSION	0x02020100
 
 /* the basics */
 #ifndef NULL
@@ -60,12 +60,14 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.129 2007/08/21 12:38:21 msk Exp $
 #define	MAXBUFRSZ		65536	/* max temp buffer size */
 #define MAXCNAMEDEPTH		3	/* max. CNAME recursion we allow */
 #define MAXHDRCNT		64	/* max. headers signed */
-#define MAXHEADER		4096	/* buffer for caching one header */
 #define MAXHEADERS		32768	/* buffer for caching headers */
 #define MAXLABELS		16	/* max. labels we allow */
 #define MAXPOLICYDEPTH		1	/* policy recursion we allow */
 #define MAXTAGNAME		8	/* biggest tag name */
 
+#define DKIM_MAXHEADER		4096	/* buffer for caching one header */
+#define	DKIM_MAXHOSTNAMELEN	256	/* max. FQDN we support */
+
 /* defaults */
 #define	DEFERRLEN		64	/* default error string length */
 #define	DEFTMPDIR		"/var/tmp"
@@ -1079,6 +1081,18 @@ extern DKIM_STAT dkim_free __P((DKIM *dkim));
 
 extern const char *dkim_geterror __P((DKIM *dkim));
 
+/*
+**  DKIM_GETRESULTSTR -- translate a DKIM_STAT_* constant to a string
+**
+**  Parameters:
+**      result -- DKIM_STAT_* constant to translate
+**
+**  Return value:
+**      Pointer to a text describing "result", or NULL if none exists
+*/
+
+extern const char *dkim_getresultstr __P((DKIM_STAT result));
+
 /*
 **  DKIM_GETPRESULT -- retrieve policy result
 **
@@ -1191,10 +1205,10 @@ extern int dkim_flush_cache __P((DKIM_LIB *lib));
 /* default list of sender headers */
 extern const u_char *default_senderhdrs[];
 
-/* default list of headers to sign */
-extern const u_char *default_signhdrs[];
+/* list of headers that should be signed, per RFC4871 section 5.5 */
+extern const u_char *should_signhdrs[];
 
-/* default list of headers to skip */
-extern const u_char *default_skiphdrs[];
+/* list of headers that should not be signed, per RFC4871 section 5.5 */
+extern const u_char *should_not_signhdrs[];
 
 #endif /* ! _DKIM_H_ */
