@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.8 2007/06/15 00:22:36 msk Exp $";
+static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.16 2007/08/08 17:54:59 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -12,6 +12,10 @@ static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.8 2007/06/15 00:22:36 msk
 #include <assert.h>
 #include <string.h>
 #include <stdio.h>
+#include <arpa/nameser.h>
+
+/* libsm includes */
+#include <sm/string.h>
 
 /* libdkim includes */
 #include "dkim.h"
@@ -29,30 +33,30 @@ int kl;
 **
 **  Parameters:
 **  	dkim -- DKIM handle
+**  	sig -- DKIM_SIGINFO handle
 **  	buf -- where to write the result
 **  	buflen -- how much space is available at "buf"
 **
 **  Return value:
-**  	1 -- policy found, returned
-**  	0 -- policy not found
+**  	0 -- operation completed
 **  	-1 -- error
 */
 
 int
-policy_lookup(DKIM *dkim, unsigned char *buf, size_t buflen)
+policy_lookup(DKIM *dkim, unsigned char *query,
+              unsigned char *buf, size_t buflen, int *qstatus)
 {
-	const char *domain;
-
 	assert(dkim != NULL);
+	assert(query != NULL);
 	assert(buf != NULL);
-
-	domain = dkim_getsigdomain(dkim);
-	assert(domain != NULL);
-	assert(strcmp(domain, DOMAIN) == 0);
+	assert(qstatus != NULL);
 
 	pl = 1;
 
-	return 0;				/* default for now */
+	sm_strlcpy(buf, DKIM_POLICY_DEFAULTTXT, buflen);
+	*qstatus = NOERROR;
+
+	return 0;
 }
 
 /*
@@ -60,6 +64,7 @@ policy_lookup(DKIM *dkim, unsigned char *buf, size_t buflen)
 **
 **  Parameters:
 **  	dkim -- DKIM handle
+**  	sig -- DKIM_SIGINFO handle
 **  	buf -- where to write the result
 **  	buflen -- how much space is available at "buf"
 **
@@ -68,19 +73,20 @@ policy_lookup(DKIM *dkim, unsigned char *buf, size_t buflen)
 */
 
 DKIM_STAT
-key_lookup(DKIM *dkim, unsigned char *buf, size_t buflen)
+key_lookup(DKIM *dkim, DKIM_SIGINFO *sig, unsigned char *buf, size_t buflen)
 {
 	const char *selector;
 	const char *domain;
 
 	assert(dkim != NULL);
+	assert(sig != NULL);
 	assert(buf != NULL);
 
-	selector = dkim_getselector(dkim);
+	selector = dkim_sig_getselector(sig);
 	assert(selector != NULL);
 	assert(strcmp(selector, SELECTOR) == 0);
 
-	domain = dkim_getsigdomain(dkim);
+	domain = dkim_sig_getdomain(sig);
 	assert(domain != NULL);
 	assert(strcmp(domain, DOMAIN) == 0);
 
@@ -113,6 +119,8 @@ main(int argc, char **argv)
 # ifdef TEST_KEEP_FILES
 	u_int flags;
 # endif /* TEST_KEEP_FILES */
+	int testpolicy;
+	int suspicious;
 	DKIM_STAT status;
 	DKIM *dkim;
 	DKIM_LIB *lib;
@@ -218,11 +226,18 @@ main(int argc, char **argv)
 	status = dkim_eom(dkim, NULL);
 	assert(status == DKIM_STAT_OK);
 
+	testpolicy = 0;
+	suspicious = 0;
+	status = dkim_policy(dkim, &testpolicy, &suspicious, NULL);
+	assert(status == DKIM_STAT_OK);
+
 	status = dkim_free(dkim);
 	assert(status == DKIM_STAT_OK);
 
 	assert(pl == 1);
 	assert(kl == 1);
+
+	dkim_close(lib);
 #endif /* ! DKIM_SIGN_RSASHA256 */
 
 	return 0;
