@@ -7,7 +7,7 @@
 #define _UTIL_H_
 
 #ifndef lint
-static char util_h_id[] = "@(#)$Id: util.h,v 1.10 2007/05/12 14:41:39 msk Exp $";
+static char util_h_id[] = "@(#)$Id: util.h,v 1.11 2007/08/15 01:14:23 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -24,8 +24,6 @@ extern void dkim_collapse __P((u_char *));
 extern bool dkim_hdrlist __P((u_char *, size_t, u_char **, bool));
 extern int dkim_hexchar __P((int c));
 extern bool dkim_islwsp __P((u_int));
-extern bool dkim_iswsp __P((u_int));
-extern void dkim_lowercase __P((u_char *));
 extern void dkim_lowerhdr __P((u_char *));
 
 #endif /* ! _UTIL_H_ */
